**********
Interfaces
**********

Interfaces for the various platforms ADLES supports.


Generic Interface
=================

.. autoclass:: adles.interfaces.interface.Interface
   :members:


vSphere Interface
=================

.. autoclass:: adles.interfaces.vsphere_interface.VsphereInterface
   :members:


Docker Interface
================

.. autoclass:: adles.interfaces.docker_interface.DockerInterface
   :members:


Cloud Interface
===============

.. autoclass:: adles.interfaces.cloud_interface.CloudInterface
   :members:
